# Author: Sebastien Verel
# Version 0
# Date: 2020/10/11

# See: https://mlopez-ibanez.github.io/eaf/
# ref: Manuel López-Ibáñez, Luís Paquete, and Thomas Stützle. Exploratory Analysis of Stochastic Local Search Algorithms in Biobjective Optimization. In Experimental Methods for the Analysis of Optimization Algorithms, pages 209–222.
library(eaf)

exo3 <- function() {
  # lecture des valeurs des objectif pour les ensembles A et B
  fA <- read.table("solution_A.csv")
  fB <- read.table("solution_B.csv")
  
  # https://mlopez-ibanez.github.io/eaf/reference/hypervolume.html
  # calcul de l'hypervolume, avec pour référence (0, 0) et en maximisation
  hypervolume(fA, reference = c(0,0), maximise = c(TRUE, TRUE))
  hypervolume(fB, reference = c(0,0), maximise = c(TRUE, TRUE))
  # comment: l'hypervolume de A est plus grand que celui de B, A est meilleur que B selon cet indicateur
  
  # https://mlopez-ibanez.github.io/eaf/reference/epsilon.html

  # calcul d'un front de référence = solutions non-dominées de (A union B)
  ref <- filter_dominated(rbind(fA, fB), maximise = c(TRUE, TRUE))
  
  # Calcul de l'indicateur epsilon pour chaque ensemble
  epsilon_additive(fA, ref, maximise = c(TRUE, TRUE))
  epsilon_additive(fB, ref, maximise = c(TRUE, TRUE))
  # comment: l'espilon indicateur de A est plus petit que celui de B, A est meilleur que B selon cet indicateur
  
  # https://mlopez-ibanez.github.io/eaf/reference/igd.html
  igd(fA, ref, maximise = c(TRUE, TRUE))
  igd(fB, ref, maximise = c(TRUE, TRUE))
  # comment: l'IGD de A est plus petit que celui de B, A est meilleur que B selon cet indicateur
  
  # https://mlopez-ibanez.github.io/eaf/reference/eafdiffplot.html
  fA$index <- rep(1, length(fA$V1))
  fB$index <- rep(2, length(fB$V1))
  
  eafdiffplot(fA, fB, type = "area", maximise = c(TRUE, TRUE), intervals = 10)
  # Permet d'observer la probabibilité d'atteindre chaque point de l'espace objectif
}
